# -*- coding: utf-8 -*-
#==========================================================#
#Last Updated - June 2018
#@author: z5025317 Valentin Heimhuber
#code for creating climate prioritization plots for NARCLIM variables. 
#Inputs: Uses CSV files that contain all 12 NARCLIM model runs time series for 1 grid cell created with: P1_NARCliM_NC_to_CSV_CCRC_SS.py

#==========================================================#
#Load packages
#==========================================================#
import numpy as np
import os
import pandas as pd
import glob
import matplotlib
import matplotlib.pyplot as plt
from datetime import datetime
from datetime import timedelta
from matplotlib.backends.backend_pdf import PdfPages
from ggplot import *
matplotlib.style.use('ggplot')

#==========================================================#
#Input parameters
#==========================================================#
# Set working direcotry (where postprocessed NARClIM data is located)
#set beginning and end years and corresponding scenario code
fs=['HCC010','HCC040']
comparison_code = '10_40'
startyear=1995
endyear=1997
year=range(startyear, endyear+1)

#set directory path for output files
output_directory = 'C:/Users/z5025317/OneDrive - UNSW/Hunter_CC_Modeling/08_Results/Output/Postprocessed' + comparison_code +'/'
variable = 'vel' #depth or vel

#set model element nodes from chainage file
node=[837, 666, 981, 59,527, 34, 391] #1, 

#set plot parameters
ALPHA_figs = 1
font = {'family' : 'sans-serif',
        'weight' : 'normal',
        'size'   : 14}
matplotlib.rc('font', **font)
#==========================================================#

#==========================================================#
#100% automated part of the code doing the data extraction
#==========================================================
Summary_df =   pd.DataFrame() 
for f in fs:
    #f= 'HCC040'
    #set input and output directories
    input_directory = 'C:/Users/z5025317/OneDrive - UNSW/Hunter_CC_Modeling/08_Results/Output/'+ f 
    #set directory path for individual png files
    png_output_directory = output_directory  + '/Figures/' 
    # Set working direcotry (where postprocessed NARClIM data is located)
    os.chdir(input_directory)
    #output_directory = 'J:/Project wrl2016032/NARCLIM_Raw_Data/Extracted'
    if not os.path.exists(output_directory):
        os.makedirs(output_directory)
        print('-------------------------------------------')
        print("output directory folder didn't exist and was generated")
        print('-------------------------------------------')
        
    #output_directory = 'J:/Project wrl2016032/NARCLIM_Raw_Data/Extracted'
    if not os.path.exists(png_output_directory):
        os.makedirs(png_output_directory)
        print('-------------------------------------------')
        print("output directory folder didn't exist and was generated")
        print('-------------------------------------------')
    #==========================================================#
    #Load data file
    if variable == 'depth':
        Clim_Var_CSVs = glob.glob('*' + variable + '*')
        clim_var_csv_path = Clim_Var_CSVs[0]
        df = pd.read_csv(clim_var_csv_path, index_col=False,  sep=' ')
        df.index = pd.to_datetime(df.Year, format = '%Y') + pd.to_timedelta(df.Hour, unit='h')
        df= df.drop(columns=['Year', 'Hour'])
    if variable == 'vel':
        #x velocity
        Clim_Var_CSVs = glob.glob('*' +'x'+ variable + '*')
        clim_var_csv_path = Clim_Var_CSVs[0]
        df = pd.read_csv(clim_var_csv_path, index_col=False,  sep=' ')
        df.index = pd.to_datetime(df.Year, format = '%Y') + pd.to_timedelta(df.Hour, unit='h')
        dfx= df.drop(columns=['Year', 'Hour','1'])
        #y velocity
        Clim_Var_CSVs = glob.glob('*' +'y'+ variable + '*')
        clim_var_csv_path = Clim_Var_CSVs[0]
        df = pd.read_csv(clim_var_csv_path, index_col=False,  sep=' ')
        df.index = pd.to_datetime(df.Year, format = '%Y') + pd.to_timedelta(df.Hour, unit='h')
        dfy= df.drop(columns=['Year', 'Hour','1'])
        df = np.sqrt(dfx*dfx + dfy*dfy)

        #if f == 'HCC040':
        #    df.index =  df.index  +  pd.to_timedelta(72, unit='h')
    #append to summary data frame
    if f == 'HCC010':
        scname = 'Present'
    if f == 'HCC011':
        scname = 'Near_Future'
        df.index =  df.index  -  (datetime.strptime('2025 01 01', '%Y %m %d').date() - datetime.strptime('1995 01 01', '%Y %m %d').date())
    if f == 'HCC012':
        scname = 'Far_Future'
        df.index =  df.index  -  (datetime.strptime('2065 01 01', '%Y %m %d').date() - datetime.strptime('1995 01 01', '%Y %m %d').date())
    if f == 'HCC040':
        scname = 'Present_Resto'
    df.columns = df.columns+'_'+ scname
    Summary_df = pd.concat([Summary_df, df], axis=1, join='outer')

#cut down the summary df to common years
Summary_df = Summary_df[datetime.strptime(str(startyear) + ' 01 05', '%Y %m %d').date():datetime.strptime(str(endyear) + ' 12 31', '%Y %m %d').date()]
Summary_df.tail()

for NODE in node:
    NODE = str(NODE)
    #=========#
    #comparison time series plot at node
    #=========#
    #out name
    png_out_file_name = comparison_code + '_' +  variable  + '_' + NODE + '_time_series.png'
    png_out_path = png_output_directory + '/' + png_out_file_name
    #
    plotin_df = Summary_df.filter(regex=NODE)
    #prepare data frame for plot
    fig = plt.figure(figsize=(14,18))
    ax=plt.subplot(4,1,1) 
    #start and end dat of plots
    plt.title(variable  + '_' + NODE + ' - time series')
    start_date = datetime(int('1996'), int('02'), int('01'))
    end_date = datetime(int('1996'), int('02'), int('5'))
    plotin_df1=plotin_df[start_date:end_date]
    ymin = min(plotin_df1.min()) - 0.01 *min(plotin_df1.min())
    ymax = max(plotin_df1.max()) + 0.01 *max(plotin_df1.max())  
    plotin_df1.plot(ylim=(ymin,ymax) ,legend=False, ax=ax) 
    #plt.legend( loc=1)    
    plt.xticks([])
    
    ax=plt.subplot(4,1,2) 
    start_date = datetime(int('1996'), int('02'), int('01'))
    end_date = datetime(int('1996'), int('02'), int('3'))
    plotin_df2=plotin_df[start_date:end_date]
    ymin = min(plotin_df2.min()) - 0.1 *min(plotin_df2.min())
    ymax = max(plotin_df2.max()) + 0.1 *max(plotin_df2.max()) 
    plotin_df2.plot(ylim=(ymin,ymax),legend=False, ax=ax)
    #plt.legend( loc=1)
    ax.xaxis.grid(False)
    
    ax=plt.subplot(4,1,3)
    plt.title(variable  + '_' + NODE + ' - monthly maximum')
    Monthly_max = plotin_df.resample('M').max()
    Monthly_max.plot(ax=ax,legend=False)
    plt.legend( loc=1)
    ax.xaxis.grid(False)
    
    ax=plt.subplot(4,1,4)
    plt.title(variable  + '_' + NODE + ' - monthly mean')
    Monthly_mean = plotin_df.resample('M').mean()
    Monthly_mean.plot(ax=ax)
    #plt.legend(bbox_to_anchor=(0., 1.02, 1., .102), loc=3,
    #   ncol=2, mode="expand", borderaxespad=0.)
    #plt.legend( loc=1)
    ax.xaxis.grid(False)

    #ax.patch.set_alpha(ALPHA_figs)
    fig.patch.set_alpha(ALPHA_figs)
    fig.tight_layout()
    fig.savefig(png_out_path)
    plt.close()
    #=========#



